Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(599)

Unified Diff: webrtc/common_video/libyuv/include/webrtc_libyuv.h

Issue 2517173004: Move VideoFrame and related declarations to webrtc/api/video. (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/common_video/libyuv/include/webrtc_libyuv.h
diff --git a/webrtc/common_video/libyuv/include/webrtc_libyuv.h b/webrtc/common_video/libyuv/include/webrtc_libyuv.h
index 3cfee01d75c9122b52bc2e31ad5fefdf06cde120..6d7ed1fd02db1bcdd9568054e7e65dd8d91d977b 100644
--- a/webrtc/common_video/libyuv/include/webrtc_libyuv.h
+++ b/webrtc/common_video/libyuv/include/webrtc_libyuv.h
@@ -18,13 +18,14 @@
#include <stdio.h>
#include <vector>
+#include "webrtc/api/video/video_frame.h"
#include "webrtc/common_types.h" // RawVideoTypes.
-#include "webrtc/common_video/rotation.h"
#include "webrtc/typedefs.h"
-#include "webrtc/video_frame.h"
namespace webrtc {
+class I420Buffer;
+
// Supported video types.
enum VideoType {
kUnknown,
@@ -97,9 +98,10 @@ int ExtractBuffer(const VideoFrame& input_frame, size_t size, uint8_t* buffer);
// Return value: 0 if OK, < 0 otherwise.
// TODO(nisse): Delete this wrapper, and let users call libyuv directly. Most
// calls pass |src_video_type| == kI420, and should use libyuv::I420Copy. The
// only exception at the time of this writing is
// VideoCaptureImpl::IncomingFrame, which still needs libyuv::ConvertToI420.
int ConvertToI420(VideoType src_video_type,
const uint8_t* src_frame,
int crop_x,
@@ -97,9 +98,10 @@ int ExtractBuffer(const VideoFrame& input_frame, size_t size, uint8_t* buffer);
// Return value: 0 if OK, < 0 otherwise.
// TODO(nisse): Delete this wrapper, and let users call libyuv directly. Most
-// calls pass |src_video_type| == kI420, and should use libyuv::I420Copy. The
-// only exception at the time of this writing is
-// VideoCaptureImpl::IncomingFrame, which still needs libyuv::ConvertToI420.
+// calls pass |src_video_type| == kI420, and should use libyuv::I420Copy. Also
+// remember to delete the I420Buffer forward declaration above. The only
+// exception at the time of this writing is VideoCaptureImpl::IncomingFrame,
+// which still needs libyuv::ConvertToI420.
int ConvertToI420(VideoType src_video_type,
const uint8_t* src_frame,

Powered by Google App Engine
This is Rietveld 408576698